@@ -5,13 +5,13 @@
 #' See the README on
 #' \href{https://github.com/cdmuir/tealeaves}{GitHub}
 #'
-#' @docType package
 #' @name tealeaves
 #' @importFrom magrittr %>% %<>%
 #' @importFrom methods is
 #' @importFrom rlang .data
 #' @importFrom units drop_units set_units
-NULL
+#' @keywords internal
+"_PACKAGE"
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
